==> ejc-sealm-impl-3.0.0-20220309.001629-53-sources.jar: com/ejianc/business/sealm/bean/ZcyysqEntity.java <==
package com.ejianc.business.sealm.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 支出合同用印申请
 * 
 * @author generator
 * 
 */
 @TableName("t_seal_zcyysq")
public class ZcyysqEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="htlx_id")
    private Long htlxId; // 合同类型id
    @TableField(value="htlx_name")
    private String htlxName; // 合同类型名称
    @TableField(value="sq_date")
    private Date sqDate; // 申请日期
    @TableField(value="ht_code")
    private String htCode; // 合同编号
    @TableField(value="ht_name")
    private String htName; // 合同名称
    @TableField(value="htje")
    private String htje; // 合同金额
    @TableField(value="babh_id")
    private Long babhId; // 备案编号id
    @TableField(value="babh_name")
    private String babhName; // 备案编号名称
    @TableField(value="htfs")
    private Integer htfs; // 合同份数（默认1）
    @TableField(value="jbr_id")
    private Long jbrId; // 经办人id
    @TableField(value="jbr_name")
    private String jbrName; // 经办人名称
    @TableField(value="jbr_tel")
    private String jbrTel; // 经办人联系方式
    @TableField(value="yycs")
    private Integer yycs; // 用印次数
    @TableField(value="yy_reason")
    private String yyReason; // 用印事由
    @TableField(value="yzlb_id")
    private Long yzlbId; // 印章类别id
    @TableField(value="yzlb_name")
    private String yzlbName; // 印章类别名称
    @TableField(value="yz_id")
    private Long yzId; // 印章id
    @TableField(value="yz_code")
    private String yzCode; // 印章编码
    @TableField(value="yz_name")
    private String yzName; // 印章名称
    @TableField(value="yzjb_id")
    private Long yzjbId; // 印章级别id
    @TableField(value="yzjb_name")
    private String yzjbName; // 印章级别名称
    @TableField(value="sf_wdgz")
    private Integer sfWdgz; // 是否外带公章，下拉选择，是或否
    @TableField(value="qz_status")
    private Integer qzStatus; // 签章状态，0未开始，1乙方签章，2甲方签章
    @TableField(value="yzm")
    private String yzm; // 验证码
    @TableField(value="yyr_id")
    private Long yyrId; // 用印人id
    @TableField(value="yyr_name")
    private String yyrName; // 用印人名称
    @TableField(value="yy_address")
    private String yyAddress; // 用印地点
    @TableField(value="yyjg")
    private String yyjg; // 用印结果
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="begin_date")
    private Date beginDate; // 开始日期
    @TableField(value="end_date")
    private Date endDate; // 结束日期
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="update_user_name")
    private String updateUserName; // 修改人
    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getHtlxId() {
        return htlxId;
    }

    public void setHtlxId(Long htlxId) {
        this.htlxId = htlxId;
    }
    public String getHtlxName() {
        return htlxName;
    }

    public void setHtlxName(String htlxName) {
        this.htlxName = htlxName;
    }
    public Date getSqDate() {
        return sqDate;
    }

    public void setSqDate(Date sqDate) {
        this.sqDate = sqDate;
    }
    public String getHtCode() {
        return htCode;
    }

    public void setHtCode(String htCode) {
        this.htCode = htCode;
    }
    public String getHtName() {
        return htName;
    }

    public void setHtName(String htName) {
        this.htName = htName;
    }
    public String getHtje() {
        return htje;
    }

    public void setHtje(String htje) {
        this.htje = htje;
    }
    public Long getBabhId() {
        return babhId;
    }

    public void setBabhId(Long babhId) {
        this.babhId = babhId;
    }
    public String getBabhName() {
        return babhName;
    }

    public void setBabhName(String babhName) {
        this.babhName = babhName;
    }
    public Integer getHtfs() {
        return htfs;
    }

    public void setHtfs(Integer htfs) {
        this.htfs = htfs;
    }
    public Long getJbrId() {
        return jbrId;
    }

    public void setJbrId(Long jbrId) {
        this.jbrId = jbrId;
    }
    public String getJbrName() {
        return jbrName;
    }

    public void setJbrName(String jbrName) {
        this.jbrName = jbrName;
    }
    public String getJbrTel() {
        return jbrTel;
    }

    public void setJbrTel(String jbrTel) {
        this.jbrTel = jbrTel;
    }
    public Integer getYycs() {
        return yycs;
    }

    public void setYycs(Integer yycs) {
        this.yycs = yycs;
    }
    public String getYyReason() {
        return yyReason;
    }

    public void setYyReason(String yyReason) {
        this.yyReason = yyReason;
    }
    public Long getYzlbId() {
        return yzlbId;
    }

    public void setYzlbId(Long yzlbId) {
        this.yzlbId = yzlbId;
    }
    public String getYzlbName() {
        return yzlbName;
    }

    public void setYzlbName(String yzlbName) {
        this.yzlbName = yzlbName;
    }
    public Long getYzId() {
        return yzId;
    }

    public void setYzId(Long yzId) {
        this.yzId = yzId;
    }
    public String getYzCode() {
        return yzCode;
    }

    public void setYzCode(String yzCode) {
        this.yzCode = yzCode;
    }
    public String getYzName() {
        return yzName;
    }

    public void setYzName(String yzName) {
        this.yzName = yzName;
    }
    public Long getYzjbId() {
        return yzjbId;
    }

    public void setYzjbId(Long yzjbId) {
        this.yzjbId = yzjbId;
    }
    public String getYzjbName() {
        return yzjbName;
    }

    public void setYzjbName(String yzjbName) {
        this.yzjbName = yzjbName;
    }
    public Integer getSfWdgz() {
        return sfWdgz;
    }

    public void setSfWdgz(Integer sfWdgz) {
        this.sfWdgz = sfWdgz;
    }
    public Integer getQzStatus() {
        return qzStatus;
    }

    public void setQzStatus(Integer qzStatus) {
        this.qzStatus = qzStatus;
    }
    public String getYzm() {
        return yzm;
    }

    public void setYzm(String yzm) {
        this.yzm = yzm;
    }
    public Long getYyrId() {
        return yyrId;
    }

    public void setYyrId(Long yyrId) {
        this.yyrId = yyrId;
    }
    public String getYyrName() {
        return yyrName;
    }

    public void setYyrName(String yyrName) {
        this.yyrName = yyrName;
    }
    public String getYyAddress() {
        return yyAddress;
    }

    public void setYyAddress(String yyAddress) {
        this.yyAddress = yyAddress;
    }
    public String getYyjg() {
        return yyjg;
    }

    public void setYyjg(String yyjg) {
        this.yyjg = yyjg;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Date getBeginDate() {
        return beginDate;
    }

    public void setBeginDate(Date beginDate) {
        this.beginDate = beginDate;
    }
    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    
}

==> ejc-sealm-impl-3.0.0-20220609.032924-87-sources.jar: com/ejianc/business/sealm/bean/ZcyysqEntity.java <==
package com.ejianc.business.sealm.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 支出合同用印申请
 * 
 * @author generator
 * 
 */
 @TableName("t_seal_zcyysq")
public class ZcyysqEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="htlx_id")
    private Long htlxId; // 合同类型id
    @TableField(value="htlx_name")
    private String htlxName; // 合同类型名称
    @TableField(value="sq_date")
    private Date sqDate; // 申请日期
    @TableField(value="ht_code")
    private String htCode; // 合同编号
    @TableField(value="ht_name")
    private String htName; // 合同名称
    @TableField(value="htje")
    private java.math.BigDecimal htje; // 合同金额
    @TableField(value="babh_id")
    private Long babhId; // 备案编号id
    @TableField(value="babh_name")
    private String babhName; // 备案编号名称
    @TableField(value="htfs")
    private Integer htfs; // 合同份数（默认1）
    @TableField(value="jbr_id")
    private Long jbrId; // 经办人id
    @TableField(value="jbr_name")
    private String jbrName; // 经办人名称
    @TableField(value="jbr_tel")
    private String jbrTel; // 经办人联系方式
    @TableField(value="yycs")
    private Integer yycs; // 用印次数
    @TableField(value="yy_reason")
    private String yyReason; // 用印事由
    @TableField(value="yzlb_id")
    private Long yzlbId; // 印章类别id
    @TableField(value="yzlb_name")
    private String yzlbName; // 印章类别名称
    @TableField(value="yz_id")
    private Long yzId; // 印章id
    @TableField(value="yz_code")
    private String yzCode; // 印章编码
    @TableField(value="yz_name")
    private String yzName; // 印章名称
    @TableField(value="yzjb_id")
    private Long yzjbId; // 印章级别id
    @TableField(value="yzjb_name")
    private String yzjbName; // 印章级别名称
    @TableField(value="sf_wdgz")
    private Integer sfWdgz; // 是否外带公章，下拉选择，是或否
    @TableField(value="qz_status")
    private Integer qzStatus; // 签章状态，0未开始，1乙方签章，2甲方签章
    @TableField(value="yzm")
    private String yzm; // 验证码
    @TableField(value="yyr_id")
    private Long yyrId; // 用印人id
    @TableField(value="yyr_name")
    private String yyrName; // 用印人名称
    @TableField(value="yy_address")
    private String yyAddress; // 用印地点
    @TableField(value="yyjg")
    private String yyjg; // 用印结果
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="begin_date")
    private Date beginDate; // 开始日期
    @TableField(value="end_date")
    private Date endDate; // 结束日期
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="update_user_name")
    private String updateUserName; // 修改人
    @TableField(value="sqdw_id")
    private Long sqdwId; // 申请单位id
    @TableField(value="sqdw_name")
    private String sqdwName; // 申请单位名称
    @TableField(value="sqxm_id")
    private Long sqxmId; // 申请项目id
    @TableField(value="sqxm_name")
    private String sqxmName; // 申请项目名称
    @TableField(value="sqr_id")
    private Long sqrId; // 申请人id
    @TableField(value="sqr_name")
    private String sqrName; // 申请人名称
    @TableField(value="yy_date")
    private Date yyDate; // 用印日期
    @TableField(value="yzbh_id")
    private Long yzbhId; // 印章编号id
    @TableField(value="yzbh_code")
    private String yzbhCode; // 印章编号code，对应印章登记里的印章编号
    @TableField(value="yzbh_name")
    private String yzbhName; // 印章编号名称
    @TableField(value="yzzd_code")
    private String yzzdCode; // 印章字典编号
    @TableField(value="yylx_id")
    private Long yylxId; // 用印类型id
    @TableField(value="yylx_name")
    private String yylxName; // 用印类型名称
    @TableField(value="zkbm_id")
    private Long zkbmId; // 业务主控部门id
    @TableField(value="zkbm_name")
    private String zkbmName; // 业务主控部门名称
    @TableField(value="xgcs")
    private Integer xgcs; // 修改次数
    @TableField(value="djlj")
    private String djlj; // 单据链接
    @TableField(value="message_from")
    private Integer messageFrom; // 单据来源（默认0）0自建，1投标报名，2资格预审，3投标文件评审，4房屋租赁合同
    @TableField(value="htlb")
    private Integer htlb; // 合同类别 0正式，1补充协议
    @TableField(value="ht_id")
    private Long htId; // 合同编号id


    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getHtlxId() {
        return htlxId;
    }

    public void setHtlxId(Long htlxId) {
        this.htlxId = htlxId;
    }
    public String getHtlxName() {
        return htlxName;
    }

    public void setHtlxName(String htlxName) {
        this.htlxName = htlxName;
    }
    public Date getSqDate() {
        return sqDate;
    }

    public void setSqDate(Date sqDate) {
        this.sqDate = sqDate;
    }
    public String getHtCode() {
        return htCode;
    }

    public void setHtCode(String htCode) {
        this.htCode = htCode;
    }
    public String getHtName() {
        return htName;
    }

    public void setHtName(String htName) {
        this.htName = htName;
    }
    public java.math.BigDecimal getHtje() {
        return htje;
    }

    public void setHtje(java.math.BigDecimal htje) {
        this.htje = htje;
    }
    public Long getBabhId() {
        return babhId;
    }

    public void setBabhId(Long babhId) {
        this.babhId = babhId;
    }
    public String getBabhName() {
        return babhName;
    }

    public void setBabhName(String babhName) {
        this.babhName = babhName;
    }
    public Integer getHtfs() {
        return htfs;
    }

    public void setHtfs(Integer htfs) {
        this.htfs = htfs;
    }
    public Long getJbrId() {
        return jbrId;
    }

    public void setJbrId(Long jbrId) {
        this.jbrId = jbrId;
    }
    public String getJbrName() {
        return jbrName;
    }

    public void setJbrName(String jbrName) {
        this.jbrName = jbrName;
    }
    public String getJbrTel() {
        return jbrTel;
    }

    public void setJbrTel(String jbrTel) {
        this.jbrTel = jbrTel;
    }
    public Integer getYycs() {
        return yycs;
    }

    public void setYycs(Integer yycs) {
        this.yycs = yycs;
    }
    public String getYyReason() {
        return yyReason;
    }

    public void setYyReason(String yyReason) {
        this.yyReason = yyReason;
    }
    public Long getYzlbId() {
        return yzlbId;
    }

    public void setYzlbId(Long yzlbId) {
        this.yzlbId = yzlbId;
    }
    public String getYzlbName() {
        return yzlbName;
    }

    public void setYzlbName(String yzlbName) {
        this.yzlbName = yzlbName;
    }
    public Long getYzId() {
        return yzId;
    }

    public void setYzId(Long yzId) {
        this.yzId = yzId;
    }
    public String getYzCode() {
        return yzCode;
    }

    public void setYzCode(String yzCode) {
        this.yzCode = yzCode;
    }
    public String getYzName() {
        return yzName;
    }

    public void setYzName(String yzName) {
        this.yzName = yzName;
    }
    public Long getYzjbId() {
        return yzjbId;
    }

    public void setYzjbId(Long yzjbId) {
        this.yzjbId = yzjbId;
    }
    public String getYzjbName() {
        return yzjbName;
    }

    public void setYzjbName(String yzjbName) {
        this.yzjbName = yzjbName;
    }
    public Integer getSfWdgz() {
        return sfWdgz;
    }

    public void setSfWdgz(Integer sfWdgz) {
        this.sfWdgz = sfWdgz;
    }
    public Integer getQzStatus() {
        return qzStatus;
    }

    public void setQzStatus(Integer qzStatus) {
        this.qzStatus = qzStatus;
    }
    public String getYzm() {
        return yzm;
    }

    public void setYzm(String yzm) {
        this.yzm = yzm;
    }
    public Long getYyrId() {
        return yyrId;
    }

    public void setYyrId(Long yyrId) {
        this.yyrId = yyrId;
    }
    public String getYyrName() {
        return yyrName;
    }

    public void setYyrName(String yyrName) {
        this.yyrName = yyrName;
    }
    public String getYyAddress() {
        return yyAddress;
    }

    public void setYyAddress(String yyAddress) {
        this.yyAddress = yyAddress;
    }
    public String getYyjg() {
        return yyjg;
    }

    public void setYyjg(String yyjg) {
        this.yyjg = yyjg;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Date getBeginDate() {
        return beginDate;
    }

    public void setBeginDate(Date beginDate) {
        this.beginDate = beginDate;
    }
    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public Long getSqdwId() {
        return sqdwId;
    }

    public void setSqdwId(Long sqdwId) {
        this.sqdwId = sqdwId;
    }
    public String getSqdwName() {
        return sqdwName;
    }

    public void setSqdwName(String sqdwName) {
        this.sqdwName = sqdwName;
    }
    public Long getSqxmId() {
        return sqxmId;
    }

    public void setSqxmId(Long sqxmId) {
        this.sqxmId = sqxmId;
    }
    public String getSqxmName() {
        return sqxmName;
    }

    public void setSqxmName(String sqxmName) {
        this.sqxmName = sqxmName;
    }
    public Long getSqrId() {
        return sqrId;
    }

    public void setSqrId(Long sqrId) {
        this.sqrId = sqrId;
    }
    public String getSqrName() {
        return sqrName;
    }

    public void setSqrName(String sqrName) {
        this.sqrName = sqrName;
    }
    public Date getYyDate() {
        return yyDate;
    }

    public void setYyDate(Date yyDate) {
        this.yyDate = yyDate;
    }
    public Long getYzbhId() {
        return yzbhId;
    }

    public void setYzbhId(Long yzbhId) {
        this.yzbhId = yzbhId;
    }
    public String getYzbhCode() {
        return yzbhCode;
    }

    public void setYzbhCode(String yzbhCode) {
        this.yzbhCode = yzbhCode;
    }
    public String getYzbhName() {
        return yzbhName;
    }

    public void setYzbhName(String yzbhName) {
        this.yzbhName = yzbhName;
    }
    public String getYzzdCode() {
        return yzzdCode;
    }

    public void setYzzdCode(String yzzdCode) {
        this.yzzdCode = yzzdCode;
    }
    public Long getYylxId() {
        return yylxId;
    }

    public void setYylxId(Long yylxId) {
        this.yylxId = yylxId;
    }
    public String getYylxName() {
        return yylxName;
    }

    public void setYylxName(String yylxName) {
        this.yylxName = yylxName;
    }
    public Long getZkbmId() {
        return zkbmId;
    }

    public void setZkbmId(Long zkbmId) {
        this.zkbmId = zkbmId;
    }
    public String getZkbmName() {
        return zkbmName;
    }

    public void setZkbmName(String zkbmName) {
        this.zkbmName = zkbmName;
    }
    public Integer getXgcs() {
        return xgcs;
    }

    public void setXgcs(Integer xgcs) {
        this.xgcs = xgcs;
    }
    public String getDjlj() {
        return djlj;
    }

    public void setDjlj(String djlj) {
        this.djlj = djlj;
    }
    public Integer getMessageFrom() {
        return messageFrom;
    }

    public void setMessageFrom(Integer messageFrom) {
        this.messageFrom = messageFrom;
    }
    public Integer getHtlb() {
        return htlb;
    }

    public void setHtlb(Integer htlb) {
        this.htlb = htlb;
    }

    public Long getHtId() {
        return htId;
    }

    public void setHtId(Long htId) {
        this.htId = htId;
    }
}
